summaryrefslogtreecommitdiffstats
path: root/kmobile/kmobiledevice.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmobile/kmobiledevice.h')
-rw-r--r--kmobile/kmobiledevice.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/kmobile/kmobiledevice.h b/kmobile/kmobiledevice.h
index f8e36ba5..111a26e5 100644
--- a/kmobile/kmobiledevice.h
+++ b/kmobile/kmobiledevice.h
@@ -35,7 +35,7 @@
#include <libkcal/event.h>
-class KConfig;
+class TDEConfig;
#define KMOBILE_MIMETYPE_DEVICE "kdedevice/mobiledevice"
#define KMOBILE_MIMETYPE_DEVICE_KONQUEROR(name) TQString("kdedevice/kmobile_%1").arg(name)
@@ -171,8 +171,8 @@ public:
const TQString nameForCap(int cap) const;
// returns an error string for the given error code
- // See KIO::buildErrorString()
- TQString buildErrorString(KIO::Error err, const TQString &errorText) const;
+ // See TDEIO::buildErrorString()
+ TQString buildErrorString(TDEIO::Error err, const TQString &errorText) const;
public:
/*
@@ -208,9 +208,9 @@ public:
/**
* helper functions for the kmobile device drivers
*/
- void createDirEntry(KIO::UDSEntry& entry, const TQString& name,
+ void createDirEntry(TDEIO::UDSEntry& entry, const TQString& name,
const TQString& url, const TQString& mime) const;
- void createFileEntry(KIO::UDSEntry& entry, const TQString& name,
+ void createFileEntry(TDEIO::UDSEntry& entry, const TQString& name,
const TQString& url, const TQString& mime,
const unsigned long size = 0) const;
/**
@@ -321,7 +321,7 @@ signals:
* mimetype, etc.
* @param _entry The UDSEntry containing all of the object attributes.
*/
- void statEntry( const KIO::UDSEntry &_entry );
+ void statEntry( const TDEIO::UDSEntry &_entry );
/**
* internal function to be called by the slave.
@@ -333,7 +333,7 @@ signals:
* @param ready set to true after emitting all items. _entry is not
* used in this case
*/
- void listEntry( const KIO::UDSEntry& _entry, bool ready);
+ void listEntry( const TDEIO::UDSEntry& _entry, bool ready);
/**
* Internal function to transmit meta data to the application.
@@ -349,7 +349,7 @@ signals:
* simple example:
*
* <pre>
- * KIO::AuthInfo authInfo;
+ * TDEIO::AuthInfo authInfo;
* if ( openPassDlg( authInfo ) )
* {
* kdDebug() << TQString::fromLatin1("User: ")
@@ -363,7 +363,7 @@ signals:
* comment as follows:
*
* <pre>
- * KIO::AuthInfo authInfo;
+ * TDEIO::AuthInfo authInfo;
* authInfo.caption= "Acme Password Dialog";
* authInfo.username= "Wile E. Coyote";
* TQString errorMsg = "You entered an incorrect password.";
@@ -384,7 +384,7 @@ signals:
* @return @p TRUE if user clicks on "OK", @p FALSE otherwsie.
* @since 3.1
*/
- bool openPassDlg( KIO::AuthInfo& info, const TQString &errorMsg );
+ bool openPassDlg( TDEIO::AuthInfo& info, const TQString &errorMsg );
/**
* Call this in @ref #mimetype, when you know the mimetype.
@@ -396,7 +396,7 @@ signals:
* Call to signal an error.
* This also finishes the job, no need to call finished.
*
* If the Error code is KIO::ERR_SLAVE_DEFINED then the
* _text should contain the complete translated text of
* of the error message. This message will be displayed
* in an KTextBrowser which allows rich text complete
@@ -404,9 +404,9 @@ signals:
* mailer, "exec:/command arg1 arg2" will be forked and
* all other links will call the default browser.
*
- * @see KIO::Error
+ * @see TDEIO::Error
* @see KTextBrowser
* @param _errid the error code from KIO::Error
* @param _text the rich text error message
*/
void error( int _errid, const TQString &_text );
@@ -458,13 +458,13 @@ signals:
* of the file
* Call in @ref listDir too, when you know the total number of items.
*/
- void totalSize( KIO::filesize_t _bytes );
+ void totalSize( TDEIO::filesize_t _bytes );
/**
* Call this during @ref #get and @ref #copy, once in a while,
* to give some info about the current state.
* Don't emit it in @ref #listDir, @ref #listEntries speaks for itself.
*/
- void processedSize( KIO::filesize_t _bytes );
+ void processedSize( TDEIO::filesize_t _bytes );
signals:
@@ -474,7 +474,7 @@ protected:
// only available to sub-classed device drivers:
void setClassType( enum ClassType ct );
void setCapabilities( int caps );
- KConfig *config() const { return m_config; };
+ TDEConfig *config() const { return m_config; };
TQString configFileName() const { return m_configFileName; };
@@ -489,7 +489,7 @@ protected:
protected:
TQMutex m_mutex; // mutex to syncronize DCOP accesses to this device
TQString m_configFileName;
- KConfig *m_config; // this is where this device should store it's configuration
+ TDEConfig *m_config; // this is where this device should store it's configuration
enum ClassType m_classType;
TQString m_deviceClassName; // e.g. "Nokia mobile phone", "MP3 Player", "Handspring Organizer"
TQString m_deviceName; // e.g. "Nokia 6310", "Opie"
@@ -396,7 +396,7 @@ signals:
* This also finishes the job, no need to call finished.
*
- * If the Error code is KIO::ERR_SLAVE_DEFINED then the
+ * If the Error code is TDEIO::ERR_SLAVE_DEFINED then the
* _text should contain the complete translated text of
* of the error message. This message will be displayed
@@ -404,9 +404,9 @@ signals:
* @see KTextBrowser
- * @param _errid the error code from KIO::Error
+ * @param _errid the error code from TDEIO::Error
* @param _text the rich text error message
*/